@@ -3,6 +3,8 @@ from ccalafiore.combinations import n_conditions_to_combinations
 from glob import glob
 import numbers
 from math import ceil
+import os
+import ccalafiore.Formatter as cc_Formatter
 
 
 def advanced_indexing(indexes_loose):
@@ -462,8 +464,104 @@ def shuffle_in_any_dimension(data, axis=0):
     return data_shuffle
 
 
+def conditions_of_txts_to_arrays(conditions_of_directories, rows, columns, dtype=None):
+
+    n_axes_directories = len(conditions_of_directories)
+    n_conditions_directories = np.empty(n_axes_directories, dtype=int)
+    for i in range(n_axes_directories):
+        n_conditions_directories[i] = len(conditions_of_directories[i])
+    # logical_indexes_conditions = n_conditions_directories > 1
+    combinations_directories = n_conditions_to_combinations(n_conditions_directories)
+    n_combinations_directories = combinations_directories.shape[0]
+    axes_directories_squeezed = n_conditions_directories > 1
+    n_axes_directories_squeezed = np.sum(axes_directories_squeezed)
+
+    try:
+        n_arrays_from_rows = len(rows)
+    except TypeError:
+        rows = [rows]
+        n_arrays_from_rows = 1
+    try:
+        n_arrays_from_columns = len(columns)
+    except TypeError:
+        columns = [columns]
+        n_arrays_from_columns = 1
+
+    if n_arrays_from_rows != n_arrays_from_columns:
+        if n_arrays_from_rows == 1:
+            rows = list(rows) * n_arrays_from_columns
+            n_arrays_from_rows = n_arrays_from_columns
+        elif n_arrays_from_columns == 1:
+            columns = list(columns) * n_arrays_from_rows
+            n_arrays_from_columns = n_arrays_from_rows
+        else:
+            raise ValueError(
+                'The following assumption is not met:\n'
+                '\t n_arrays_from_rows' + ' \u003D ' + 'n_arrays_from_columns')
+
+    n_arrays = n_arrays_from_rows
+    # try:
+    #     n_dtypes = len(dtype)
+    # except TypeError:
+    #     dtype = [dtype]
+    #     n_dtypes = 1
+    # if n_arrays != n_dtypes:
+    #     if n_dtypes == 1:
+    #         dtype = list(dtype) * n_arrays
+    #     else:
+    #         raise ValueError(
+    #             'The following assumption is not met:\n'
+    #             '\t(n_dtypes \u003D n_arrays_from_rows) AND (n_dtypes \u003D n_arrays_from_columns)')
+
+    n_axes_per_text = 2
+    indexes = [None] * n_arrays
+    arrays = [None] * n_arrays
+    for a in range(n_arrays):
+        indexes[a] = tuple(cc_Formatter.numeric_indexes_to_slice([rows[a], columns[a]]))
+        # indexes[a] = tuple(cc_Formatter.numeric_indexes_to_slice(indexes[a]))
+
+    directory_text_0 = os.path.join(*[
+        conditions_of_directories[i][0] for i in range(n_axes_directories)])
+    array_text_0 = np.genfromtxt(directory_text_0, delimiter=',', dtype=dtype)
+    if dtype is None:
+        dtype = array_text_0.dtype
+    # axes_squeezed = [None] * n_arrays
+    indexes_out = [None] * n_arrays
+    for a in range(n_arrays):
+        array_a_d = array_text_0[indexes[a]]
+        shape_array_a_d = np.asarray(array_a_d.shape, dtype=int)
+        shape_array_a = np.append(
+            n_conditions_directories[axes_directories_squeezed], shape_array_a_d)
+        # axes_squeezed[a] = shape_array_a > 1
+        # shape_array_a = shape_array_a[axes_squeezed[a]]
+        arrays[a] = np.empty(shape_array_a, dtype=dtype)
+        n_axes_a = shape_array_a.size
+        indexes_out[a] = np.empty(n_axes_a, dtype=object)
+        indexes_out[a][:] = slice(None)
+
+    for d in range(n_combinations_directories):
+
+        directory_text_d = os.path.join(*[
+            conditions_of_directories[i][combinations_directories[d, i]] for i in range(n_axes_directories)])
+
+        array_text_d = np.genfromtxt(directory_text_d, delimiter=',', dtype=dtype)
+        for a in range(n_arrays):
+
+            indexes_out[a][slice(0, n_axes_directories_squeezed, 1)] = (
+                combinations_directories[d, axes_directories_squeezed])
+
+            array_a_d = array_text_d[indexes[a]]
+
+            arrays[a][tuple(indexes_out[a])] = array_a_d
+
+    return arrays
+
+
 def n_csv_files_to_array(directories_csv_files, names_csv_files_in_directories=False, rows=slice(None), columns=slice(None), data_type=None):
 
+    print('using the funtion n_csv_files_to_array().\n'
+          'In the future versions of ccalafiore, it will be removed.\n'
+          'Consider using conditions_of_txts_to_arrays()')
     array = None
 
     n_axes_directories = len(directories_csv_files)
@@ -480,16 +578,13 @@ def n_csv_files_to_array(directories_csv_files, names_csv_files_in_directories=F
 
         directory = directories_csv_files[0][combinations_directories[d, 0]]
         for a in range(1, n_axes_directories):
-
-            directory = '/'.join([
-                directory,
-                directories_csv_files[a][combinations_directories[d, a]]
-            ])
+            directory = os.path.join(
+                directory, directories_csv_files[a][combinations_directories[d, a]])
 
         if names_csv_files_in_directories:
             files_per_directory = [directory]
         else:
-            files_per_directory = glob('/'.join([directory, '*.csv']))
+            files_per_directory = glob(os.path.join(directory, '*.csv'))
 
         n_files_per_directory = len(files_per_directory)
 
